# Setting Up the Jira Integration
### On this page
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#prerequisites)
  * [Step 1: Add the Jira Integration](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#step-1:-add-the-jira-integration)
  * [Step 2: Select a Jira Project](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#step-2:-select-a-jira-project)
  * [Step 3: Configure General Field Mapping (Optional)](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#step-3:-configure-general-field-mapping-\(optional\))
  * [Step 4: Configure Milestone Mapping (Optional)](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#step-4:-configure-milestone-mapping-\(optional\))
  * [Step 5: Define the Completion Status](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#step-5:-define-the-completion-status)
  * [Step 6: Configure the Execution Status Calculation (Optional)](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#step-6:-configure-the-execution-status-calculation-\(optional\))
  * [Next Steps](https://help.sap.com/docs/leanix/ea/setting-up-jira-cloud-projects-integration#next-steps)


Learn how to set up a secure connection to your Jira instance, configure project and field mappings, and prepare your environment for seamless data flow between Jira and SAP LeanIX.
